[![docs](https://img.shields.io/badge/info-documentation-informational)](https://ftag-salt.docs.cern.ch/)

# Salt

This is the home of Salt, a framework for training multi-model and multi-task models models in the style of GN2.

Documentation is available [here](https://ftag-salt.docs.cern.ch/).
